<?php


namespace MirfalahTech\Laravel\Payment\Gateway\RazerPay;


use Illuminate\Contracts\Config\Repository;
use Illuminate\Contracts\Container\BindingResolutionException;
use Illuminate\Support\ServiceProvider;
use MirfalahTech\Laravel\Payment\Manager\PaymentManager;

class RazerPayServiceProvider extends ServiceProvider
{
    /**
     * @throws BindingResolutionException
     */
    public function boot()
    {
        /** @var Repository $config */
        $config = $this->app->make('config');

        $config->set('payment.gateway.razerpay', array_merge(
            [
                'endpoint' => env('RAZER_ENDPOINT', 'https://www.onlinepayment.com.my/'),
                'merchant_id' => env('RAZER_MERCHANT_ID'),
                'verify_key' => env('RAZER_VERIFY_KEY'),
                'secret_key' => env('RAZER_SECRET_KEY'),
            ],
            $config->get('payment.gateway.razerpay', []) ?? []
        ));

        $this->app->afterResolving('payment', function (PaymentManager $manager) use ($config) {
            $manager->extend('razerpay', function () use ($config) {
                return new RazerPayDriver($config, $this->app->make('events'));
            });
        });
    }
}